jokes = [
    "How do you get 100 babies into a bucket? With a blender.",
    "How do you get them out again? With Doritos.",
    "How many babies does it take to paint a house? Depends how hard you throw them."
]

inspirations = [
    "I have not failed. I've just found 10,000 ways that won't work.",
    "There is no greater agony than bearing an untold story inside you."
]

idioms = [
    "A blessing in disguise",
    "Bite the bullet"
]

news = [
    "Today is sunny",
    "Tomorrow the sun will rise"
]
data = {
    'jokes': jokes,
    'inspirations': inspirations,
    'idioms': idioms,
    'news': news
}